@@ -1,5 +1,4 @@
 from ._version import __version__
-from fileformats.core import import_converters
 from .base import MedicalImage, NeuroImage
 from .misc import (  # noqa: F401
     Analyze,
@@ -38,5 +37,3 @@ from .raw import (  # noqa: F401
     # CustomKspace,
     Rda,
 )
-
-import_converters(__name__)
